<?php
/**
 * Edit Product Review Group Page
 *
 * @package ProductReviewPlugin
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

global $wpdb;
$group_table = $wpdb->prefix . 'product_review_groups';
$review_table = $wpdb->prefix . 'product_reviews';

$group_id = isset( $_GET['id'] ) ? intval( $_GET['id'] ) : 0;
$group = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM {$group_table} WHERE id = %d", $group_id ) );

if ( ! $group ) {
    wp_die( esc_html__( 'Product review group not found', 'product-review-plugin' ) );
}

$reviews = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM {$review_table} WHERE group_id = %d", $group_id ) );

$is_premium = ProductReviewPlugin::is_premium_user();
$max_reviews = $is_premium ? PHP_INT_MAX : 2;
?>

<div class="wrap">
    <h1><?php esc_html_e( 'Edit Product Review Group', 'product-review-plugin' ); ?></h1>

    <form method="post" action="<?php echo esc_url( admin_url( 'admin-post.php' ) ); ?>" id="product-review-group-form">
        <input type="hidden" name="action" value="edit_product_review_group">
        <input type="hidden" name="group_id" value="<?php echo esc_attr( $group_id ); ?>">
        <?php wp_nonce_field( 'edit_product_review_group_nonce' ); ?>

        <table class="form-table">
            <tr>
                <th scope="row"><label for="group_label"><?php esc_html_e( 'Group Label', 'product-review-plugin' ); ?></label></th>
                <td><input name="group_label" type="text" id="group_label" class="regular-text" value="<?php echo esc_attr( $group->group_label ); ?>" required></td>
            </tr>
        </table>

        <div id="review-forms-container">
            <?php 
            if (empty($reviews)) {
                // If there are no reviews, add an empty form
                $reviews = [new stdClass()];
            }
            foreach ( $reviews as $index => $review ) : 
                $review = (object)$review; // Ensure $review is an object
            ?>
                <div class="review-form" data-review-index="<?php echo esc_attr( $index ); ?>">
                    <h3><?php echo esc_html( sprintf( __( 'Product Review #%d', 'product-review-plugin' ), $index + 1 ) ); ?></h3>
                    <table class="form-table">
                        <tr>
                            <th scope="row"><label for="product_name_<?php echo esc_attr( $index ); ?>"><?php esc_html_e( 'Product Name', 'product-review-plugin' ); ?></label></th>
                            <td><input name="product_name[]" type="text" id="product_name_<?php echo esc_attr( $index ); ?>" class="regular-text" value="<?php echo esc_attr( $review->product_name ?? '' ); ?>" required></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="product_category_<?php echo esc_attr( $index ); ?>"><?php esc_html_e( 'Product Category', 'product-review-plugin' ); ?></label></th>
                            <td><input name="product_category[]" type="text" id="product_category_<?php echo esc_attr( $index ); ?>" class="regular-text" value="<?php echo esc_attr( $review->product_category ?? '' ); ?>" required></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="product_rating_<?php echo esc_attr( $index ); ?>"><?php esc_html_e( 'Product Rating', 'product-review-plugin' ); ?></label></th>
                            <td><input name="product_rating[]" type="number" id="product_rating_<?php echo esc_attr( $index ); ?>" class="small-text" step="0.1" min="0" max="5" value="<?php echo esc_attr( $review->product_rating ?? '' ); ?>" required></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="product_price_<?php echo esc_attr( $index ); ?>"><?php esc_html_e( 'Product Price', 'product-review-plugin' ); ?></label></th>
                            <td><input name="product_price[]" type="number" id="product_price_<?php echo esc_attr( $index ); ?>" class="regular-text" step="0.01" value="<?php echo esc_attr( $review->product_price ?? '' ); ?>" required></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="product_summary_<?php echo esc_attr( $index ); ?>"><?php esc_html_e( 'Product Summary', 'product-review-plugin' ); ?></label></th>
                            <td><textarea name="product_summary[]" id="product_summary_<?php echo esc_attr( $index ); ?>" rows="5" cols="50" required><?php echo esc_textarea( $review->product_summary ?? '' ); ?></textarea></td>
                        </tr>
                        <tr>
    <th scope="row">
        <label for="product_image_<?php echo esc_attr($index); ?>">
            <?php esc_html_e('Product Image', 'product-review-plugin'); ?>
        </label>
    </th>
    <td>
        <div class="image-upload-container">
            <input type="text" 
                   name="product_image[]" 
                   id="product_image_<?php echo esc_attr($index); ?>" 
                   class="regular-text" 
                   value="<?php echo isset($review->image_url) ? esc_url($review->image_url) : ''; ?>">
            <button type="button" class="button upload-image-button">
                <?php esc_html_e('Upload Image', 'product-review-plugin'); ?>
            </button>
            <div class="media-preview"></div>
        </div>
    </td>
</tr>
                        <tr>
                            <th scope="row"><label for="product_description_<?php echo esc_attr( $index ); ?>"><?php esc_html_e( 'Description', 'product-review-plugin' ); ?></label></th>
                            <td><textarea name="product_description[]" id="product_description_<?php echo esc_attr( $index ); ?>" rows="5" cols="50"><?php echo esc_textarea( $review->description ?? '' ); ?></textarea></td>
                        </tr>
                        <tr>
                            <th scope="row"><label><?php esc_html_e( 'Features', 'product-review-plugin' ); ?></label></th>
                            <td>
                                <table class="features-table">
                                    <tr>
                                        <th><?php esc_html_e( 'Feature', 'product-review-plugin' ); ?></th>
                                        <th><?php esc_html_e( 'Value', 'product-review-plugin' ); ?></th>
                                        <th><?php esc_html_e( 'Action', 'product-review-plugin' ); ?></th>
                                    </tr>
                                    <?php
                                    $features = json_decode( $review->product_features ?? '[]', true );
                                    if ( is_array( $features ) ) {
                                        foreach ( $features as $feature ) {
                                            echo '<tr>';
                                            echo '<td><input type="text" name="feature_name[' . esc_attr( $index ) . '][]" value="' . esc_attr( $feature['name'] ) . '"></td>';
                                            echo '<td><input type="text" name="feature_value[' . esc_attr( $index ) . '][]" value="' . esc_attr( $feature['value'] ) . '"></td>';
                                            echo '<td><button type="button" class="remove-feature button">' . esc_html__( 'Remove', 'product-review-plugin' ) . '</button></td>';
                                            echo '</tr>';
                                        }
                                    }
                                    ?>
                                </table>
                                <button type="button" class="add-feature button"><?php esc_html_e( 'Add Feature', 'product-review-plugin' ); ?></button>
                            </td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="product_pros_<?php echo esc_attr( $index ); ?>"><?php esc_html_e( 'Pros (one per line)', 'product-review-plugin' ); ?></label></th>
                            <td><textarea name="product_pros[]" id="product_pros_<?php echo esc_attr( $index ); ?>" rows="5" cols="50" required><?php echo esc_textarea( $review->product_pros ?? '' ); ?></textarea></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="product_cons_<?php echo esc_attr( $index ); ?>"><?php esc_html_e( 'Cons (one per line)', 'product-review-plugin' ); ?></label></th>
                            <td><textarea name="product_cons[]" id="product_cons_<?php echo esc_attr( $index ); ?>" rows="5" cols="50" required><?php echo esc_textarea( $review->product_cons ?? '' ); ?></textarea></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="product_who_should_buy_<?php echo esc_attr( $index ); ?>"><?php esc_html_e( 'Who Should Buy (one per line)', 'product-review-plugin' ); ?></label></th>
                            <td><textarea name="product_who_should_buy[]" id="product_who_should_buy_<?php echo esc_attr( $index ); ?>" rows="5" cols="50" required><?php echo esc_textarea( $review->product_who_should_buy ?? '' ); ?></textarea></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="button_text_<?php echo esc_attr( $index ); ?>"><?php esc_html_e( 'Button Text', 'product-review-plugin' ); ?></label></th>
                            <td><input type="text" name="button_text[]" id="button_text_<?php echo esc_attr( $index ); ?>" value="<?php echo esc_attr( $review->button_text ?? '' ); ?>"></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="button_url_<?php echo esc_attr( $index ); ?>"><?php esc_html_e( 'Button URL', 'product-review-plugin' ); ?></label></th>
                            <td><input type="text" name="button_url[]" id="button_url_<?php echo esc_attr( $index ); ?>" value="<?php echo esc_url( $review->button_url ?? '' ); ?>"></td>
                        </tr>
                    </table>
                    <?php if ($index > 0): ?>
                        <button type="button" class="button remove-review-form"><?php esc_html_e( 'Remove This Review', 'product-review-plugin' ); ?></button>
                    <?php endif; ?>
                </div>
            <?php endforeach; ?>
        </div>
        
        <button type="button" id="add-review-form" class="button"><?php esc_html_e( 'Add Another Review', 'product-review-plugin' ); ?></button>

        <?php if ( ! $is_premium ) : ?>
            <p class="description">
                <?php
                echo sprintf(
                    esc_html__( 'Free users can add up to %1$s product reviews per group. %2$sUpgrade to add more!%3$s', 'product-review-plugin' ),
                    $max_reviews,
                    '<a href="https://teclans.info/store/product/product-review-plugin/">',
                    '</a>'
                );
                ?>
            </p>
        <?php endif; ?>

        <?php submit_button( esc_html__( 'Update Product Review Group', 'product-review-plugin' ) ); ?>
    </form>
</div>

<script type="text/template" id="review-form-template">
<div class="review-form" data-review-index="{{index}}">
    <h3><?php esc_html_e( 'Product Review #{{reviewNumber}}', 'product-review-plugin' ); ?></h3>
    <table class="form-table">
        <tr>
            <th scope="row"><label for="product_name_{{index}}"><?php esc_html_e( 'Product Name', 'product-review-plugin' ); ?></label></th>
            <td><input name="product_name[]" type="text" id="product_name_{{index}}" class="regular-text" required></td>
        </tr>
        <tr>
            <th scope="row"><label for="product_category_{{index}}"><?php esc_html_e( 'Product Category', 'product-review-plugin' ); ?></label></th>
            <td><input name="product_category[]" type="text" id="product_category_{{index}}" class="regular-text" required></td>
        </tr>
        <tr>
            <th scope="row"><label for="product_rating_{{index}}"><?php esc_html_e( 'Product Rating', 'product-review-plugin' ); ?></label></th>
            <td><input name="product_rating[]" type="number" id="product_rating_{{index}}" class="small-text" step="0.1" min="0" max="5" required></td>
        </tr>
        <tr>
            <th scope="row"><label for="product_price_{{index}}"><?php esc_html_e( 'Product Price', 'product-review-plugin' ); ?></label></th>
            <td><input name="product_price[]" type="number" id="product_price_{{index}}" class="regular-text" step="0.01" required></td>
        </tr>
        <tr>
            <th scope="row"><label for="product_summary_{{index}}"><?php esc_html_e( 'Product Summary', 'product-review-plugin' ); ?></label></th>
            <td><textarea name="product_summary[]" id="product_summary_{{index}}" rows="5" cols="50" required></textarea></td>
        </tr>
        <tr>
        <th scope="row">
            <label for="product_image_{{index}}">
                <?php esc_html_e('Product Image', 'product-review-plugin'); ?>
            </label>
        </th>
        <td>
            <div class="image-upload-container">
                <input type="text" 
                       name="product_image[]" 
                       id="product_image_{{index}}" 
                       class="regular-text">
                <button type="button" class="button upload-image-button">
                    <?php esc_html_e('Upload Image', 'product-review-plugin'); ?>
                </button>
                <div class="media-preview"></div>
            </div>
        </td>
    </tr>
        <tr>
            <th scope="row"><label for="product_description_{{index}}"><?php esc_html_e( 'Description', 'product-review-plugin' ); ?></label></th>
            <td><textarea name="product_description[]" id="product_description_{{index}}" rows="5" cols="50"></textarea></td>
        </tr>
        <tr>
            <th scope="row"><label><?php esc_html_e( 'Features', 'product-review-plugin' ); ?></label></th>
            <td>
                <table class="features-table">
                    <thead>
                        <tr>
                            <th><?php esc_html_e( 'Feature', 'product-review-plugin' ); ?></th>
                            <th><?php esc_html_e( 'Value', 'product-review-plugin' ); ?></th>
                            <th><?php esc_html_e( 'Action', 'product-review-plugin' ); ?></th>
                        </tr>
                    </thead>
                    <tbody></tbody>
                </table>
                <button type="button" class="add-feature button"><?php esc_html_e( 'Add Feature', 'product-review-plugin' ); ?></button>
            </td>
        </tr>
        <tr>
            <th scope="row"><label for="product_pros_{{index}}"><?php esc_html_e( 'Pros (one per line)', 'product-review-plugin' ); ?></label></th>
            <td><textarea name="product_pros[]" id="product_pros_{{index}}" rows="5" cols="50" required></textarea></td>
        </tr>
        <tr>
            <th scope="row"><label for="product_cons_{{index}}"><?php esc_html_e( 'Cons (one per line)', 'product-review-plugin' ); ?></label></th>
            <td><textarea name="product_cons[]" id="product_cons_{{index}}" rows="5" cols="50" required></textarea></td>
        </tr>
        <tr>
            <th scope="row"><label for="product_who_should_buy_{{index}}"><?php esc_html_e( 'Who Should Buy (one per line)', 'product-review-plugin' ); ?></label></th>
            <td><textarea name="product_who_should_buy[]" id="product_who_should_buy_{{index}}" rows="5" cols="50" required></textarea></td>
        </tr>
        <tr>
            <th scope="row"><label for="button_text_{{index}}"><?php esc_html_e( 'Button Text', 'product-review-plugin' ); ?></label></th>
            <td><input type="text" name="button_text[]" id="button_text_{{index}}" value="<?php esc_attr_e( 'Add to Cart', 'product-review-plugin' ); ?>"></td>
        </tr>
        <tr>
            <th scope="row"><label for="button_url_{{index}}"><?php esc_html_e( 'Button URL', 'product-review-plugin' ); ?></label></th>
            <td><input type="text" name="button_url[]" id="button_url_{{index}}"></td>
        </tr>
    </table>
    <!-- Note: No action buttons here - they will be added by JavaScript -->
</div>
</script>
<?php
wp_localize_script('product-review-admin-script', 'productReviewL10n', array(
    'maxReviewsMessage' => __('You have reached the maximum number of reviews allowed for free users. Please upgrade to add more.', 'product-review-plugin'),
    'minReviewMessage' => __('You must have at least one review form.', 'product-review-plugin'),
    'reviewNumberText' => __('Product Review #', 'product-review-plugin'),
    'removeText' => __('Remove', 'product-review-plugin'),
    'chooseImageText' => __('Choose Image', 'product-review-plugin'),
    'useThisImageText' => __('Use this image', 'product-review-plugin'),
    'removeImageText' => __('Remove image', 'product-review-plugin'),
    'uploadImageText' => __('Upload Image', 'product-review-plugin')
));
wp_enqueue_media();
wp_enqueue_script( 'product-review-admin-script', plugin_dir_url( __FILE__ ) . '../assets/js/admin-script.js', array( 'jquery' ), '1.0', true );
wp_localize_script( 'product-review-admin-script', 'productReviewSettings', array(
    'isPremiumUser' => $is_premium,
    'maxReviews' => $max_reviews,
    'ajaxurl' => admin_url( 'admin-ajax.php' ),
    'nonce' => wp_create_nonce( 'product_review_nonce' )
) );
?>